==> identity-spi-4.0.8.Final-sources.jar: org/jboss/security/identity/IdentityFactory.java <==
/*
  * JBoss, Home of Professional Open Source
  * Copyright 2007, JBoss Inc., and individual contributors as indicated
  * by the @authors tag. See the copyright.txt in the distribution for a
  * full listing of individual contributors.
  *
  * This is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as
  * published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
  *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this software; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
  */
package org.jboss.security.identity;

import java.security.Principal;
import java.security.cert.X509Certificate;

import org.jboss.security.ErrorCodes;
import org.jboss.security.identity.extensions.CertificateIdentityFactory;
import org.jboss.security.identity.extensions.CredentialIdentityFactory;
 
/**
 *  IdentityFactory to create Identities
 *  @author Anil.Saldhana@redhat.com
 *  @since  Apr 23, 2008 
 *  @version $Revision$
 */
public class IdentityFactory
{   
   public static IdentityFactory getFactory(IdentityType type)
   {
      if(type == IdentityType.CREDENTIAL)
         return CredentialIdentityFactory.getInstance();
      
      if(type == IdentityType.CERTIFICATE)
         return  CertificateIdentityFactory.getInstance();
      
      throw new RuntimeException(ErrorCodes.NOT_YET_IMPLEMENTED + type.name());
   } 
   
   public static Identity getIdentity( Principal principal, Object credential )
   {
      return CredentialIdentityFactory.createIdentity( principal, credential ); 
   }
   
   public  static Identity  getIdentity(final Principal principal,
         final X509Certificate[] certs, final Role roles)
   {
      CertificateIdentityFactory identityFactory = CertificateIdentityFactory.getInstance();
      return identityFactory.createIdentity(principal, certs, roles); 
   }
}

==> identity-spi-4.0.12.Final-sources.jar: org/jboss/security/identity/IdentityFactory.java <==
/*
  * JBoss, Home of Professional Open Source
  * Copyright 2007, JBoss Inc., and individual contributors as indicated
  * by the @authors tag. See the copyright.txt in the distribution for a
  * full listing of individual contributors.
  *
  * This is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as
  * published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
  *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this software; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
  */
package org.jboss.security.identity;

import java.security.Principal;
import java.security.cert.X509Certificate;

import org.jboss.security.PicketBoxMessages;
import org.jboss.security.identity.extensions.CertificateIdentityFactory;
import org.jboss.security.identity.extensions.CredentialIdentityFactory;
 
/**
 *  IdentityFactory to create Identities
 *  @author Anil.Saldhana@redhat.com
 *  @since  Apr 23, 2008 
 *  @version $Revision$
 */
public class IdentityFactory
{   
   public static IdentityFactory getFactory(IdentityType type)
   {
      if(type == IdentityType.CREDENTIAL)
         return CredentialIdentityFactory.getInstance();
      
      if(type == IdentityType.CERTIFICATE)
         return  CertificateIdentityFactory.getInstance();

      throw PicketBoxMessages.MESSAGES.identityTypeFactoryNotImplemented(type != null ? type.name() : null);
   }
   
   public static Identity getIdentity( Principal principal, Object credential )
   {
      return CredentialIdentityFactory.createIdentity( principal, credential ); 
   }
   
   public  static Identity  getIdentity(final Principal principal,
         final X509Certificate[] certs, final Role roles)
   {
      CertificateIdentityFactory identityFactory = CertificateIdentityFactory.getInstance();
      return identityFactory.createIdentity(principal, certs, roles); 
   }
}
